OneShotBlog(TM)

# One. Shot. Blog.

- latest
- about
- help

- Software Copyright (C) 2009 Zed Shaw. Posts Copyright by their owners, sue them.

## SPAM SPAM SPAM spam spam...

Thanks for marking that as spam. Use your back button technology to continue with your day.

It won't go away for a little while, but unlike craigslist, we'll actually train a real spam database and prevent future spam submissions like this.